summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJean-Philippe Lang <jp_lang@yahoo.fr>2010-10-22 22:13:39 +0000
committerJean-Philippe Lang <jp_lang@yahoo.fr>2010-10-22 22:13:39 +0000
commited608cb7d39ff1224a4d1cad4b96ba0fa3505947 (patch)
treee8babe00a73ee252acd62cefaec5f8c534b8b1d9
parentb7e3f80e14e56d8d776e0fef1807b936d11adfb0 (diff)
downloadredmine-ed608cb7d39ff1224a4d1cad4b96ba0fa3505947.tar.gz
redmine-ed608cb7d39ff1224a4d1cad4b96ba0fa3505947.zip
Fixed: error on gantt when no issue have a due date (#6350).
git-svn-id: svn+ssh://rubyforge.org/var/svn/redmine/trunk@4280 e93f8b46-1217-0410-a6f0-8f06a7374b81
-rw-r--r--lib/redmine/helpers/gantt.rb6
-rw-r--r--test/functional/gantts_controller_test.rb12
2 files changed, 14 insertions, 4 deletions
diff --git a/test/functional/gantts_controller_test.rb b/test/functional/gantts_controller_test.rb
index ffc799b25..4c891c3d0 100644
--- a/test/functional/gantts_controller_test.rb
+++ b/test/functional/gantts_controller_test.rb
@@ -21,7 +21,7 @@ class GanttsControllerTest < ActionController::TestCase
assert_select "div a.issue", /##{i.id}/
end
- should_eventually "work without issue due dates" do
+ should "work without issue due dates" do
Issue.update_all("due_date = NULL")
get :show, :project_id => 1
@@ -29,6 +29,16 @@ class GanttsControllerTest < ActionController::TestCase
assert_template 'show.html.erb'
assert_not_nil assigns(:gantt)
end
+
+ should "work without issue and version due dates" do
+ Issue.update_all("due_date = NULL")
+ Version.update_all("effective_date = NULL")
+
+ get :show, :project_id => 1
+ assert_response :success
+ assert_template 'show.html.erb'
+ assert_not_nil assigns(:gantt)
+ end
should "work cross project" do
get :show
diff --git a/lib/redmine/helpers/gantt.rb b/lib/redmine/helpers/gantt.rb
index cec323720..0f86648e7 100644
--- a/lib/redmine/helpers/gantt.rb
+++ b/lib/redmine/helpers/gantt.rb
@@ -283,8 +283,8 @@ module Redmine
end
def line_for_project(project, options)
- # Skip versions that don't have a start_date
- if project.is_a?(Project) && project.start_date
+ # Skip versions that don't have a start_date or due date
+ if project.is_a?(Project) && project.start_date && project.due_date
options[:zoom] ||= 1
options[:g_width] ||= (self.date_to - self.date_from + 1) * options[:zoom]
@@ -419,7 +419,7 @@ module Redmine
def line_for_version(version, options)
# Skip versions that don't have a start_date
- if version.is_a?(Version) && version.start_date
+ if version.is_a?(Version) && version.start_date && version.due_date
options[:zoom] ||= 1
options[:g_width] ||= (self.date_to - self.date_from + 1) * options[:zoom]